@@ -8,7 +8,7 @@ import modelx as mx
 import pandas as pd
 import matplotlib.pyplot as plt
 import seaborn as sns
-sns.set()
+sns.set_theme(style="darkgrid")
 
 model = mx.read_model("model")
 
